{% extends "base.html" %}

{% block extra_css %}
  {{ super() }}
  :root {
    --pico-font-family: "commeregular";
    --pico-spacing: 0.25rem;
  }
  em, i {
    font-family: "commeregular";
    font-style: italic;
  }
  strong, b {
    font-family: "commeregular";
    font-weight: bold;
  }
  h1, h3, h4, h5, h6 {
    font-family: "dm_serif_displayregular";
    font-weight: normal;
    font-style: normal;
  }
  h2 {
    font-family: "dm_serif_displayitalic";
    font-weight: normal;
    font-style: normal;
  }
  h3 em, h3 i,
  h4 em, h4 i,
  h5 em, h5 i,
  h6 em, h6 i,
  nav {
    font-family: "dm_serif_displayitalic";
    font-weight: normal;
    font-style: normal;
  }
{% endblock extra_css %}

{% block menu %}
  <nav class="header">
    <ul>
      <li>Dernière mise à jour : {{ numeros.0.articles.0.date.strftime('%d %B %Y')}}</li>
      {% if not settings.without_search %}
        <li class="muted" aria-hidden="true"> ⁙ </li>
        <li><a href="{{ base_url }}recherche/" {% if is_search %}aria-current="page"{% endif %}>Recherche</a></li>
      {% endif %}
    </ul>
  </nav>
{% endblock menu %}
